@@ -4,17 +4,17 @@
 ** This file was originally taken from the pidentd 2.x software package.
 ** The original copyright notice is as follows:
 **
-**      This program is in the public domain and may be used freely
-**      by anyone who wants to.
+**		This program is in the public domain and may be used freely
+**		by anyone who wants to.
 **
 ** The IP masquerading functionality has been taken from openbsd.c and
 ** is distributed under the same copyright.
 **
 ** This file has been modified for oidentd by Ryan McCabe <odin@numb.org>
 **
-** Modifications Copyright (C) 1998-2001 Ryan McCabe <odin@numb.org>
+** Modifications Copyright (C) 1998-2002 Ryan McCabe <odin@numb.org>
 **
-** $Id: freebsd.c,v 1.1 2001/12/29 16:30:25 odin Exp $
+** $Id: freebsd.c,v 1.10 2002/01/18 04:50:03 odin Exp $
 */
 
 #include <config.h>
@@ -64,7 +64,6 @@
 #ifdef MASQ_SUPPORT
 #	include <netinet/ip_compat.h>
 #	include <netinet/ip_fil.h>
-#	include <netinet/ip_proxy.h>
 #	include <netinet/ip_nat.h>
 #endif
 
@@ -134,6 +133,11 @@ int k_open(void) {
 		return (-1);
 	}
 
+#ifdef MASQ_SUPPORT
+	if (kinfo->nl[N_NATLIST].n_value == 0)
+		disable_opt(MASQ);
+#endif
+
 	return (0);
 }
 
@@ -175,23 +179,15 @@ static struct socket *getlist4(	void *arg,
 
 	do {
 #ifdef MASQ_SUPPORT
-        if (opt_enabled(PROXY)) {
-            if (faddr->s_addr == SIN4(&proxy)->sin_addr.s_addr &&
-                laddr->s_addr != SIN4(&proxy)->sin_addr.s_addr &&
-                pcb.inp_fport == fport &&
-                pcb.inp_lport == lport)
-            {
-                return (pcb.inp_socket);
-            }
-
-            if (pcb.inp_faddr.s_addr == faddr->s_addr &&
-                pcb.inp_laddr.s_addr == laddr->s_addr &&
-                pcb.inp_fport == fport &&
-                pcb.inp_lport == lport)
-            {
-                return (pcb.inp_socket);
-            }
-        }
+		if (opt_enabled(PROXY)) {
+			if (faddr->s_addr == SIN4(&proxy)->sin_addr.s_addr &&
+				laddr->s_addr != SIN4(&proxy)->sin_addr.s_addr &&
+				pcbp->inp_fport == fport &&
+				pcbp->inp_lport == lport)
+			{
+				return (pcb.inp_socket);
+			}
+		}
 #endif
 
 		if (pcbp->inp_faddr.s_addr == faddr->s_addr &&
@@ -228,6 +224,18 @@ static struct socket *getlist4(	void *arg,
 		if (getbuf((u_long) head, &pcbp, sizeof(struct inpcb)) == -1)
 			break;
 
+#ifdef MASQ_SUPPORT
+		if (opt_enabled(PROXY)) {
+			if (faddr->s_addr == SIN4(&proxy)->sin_addr.s_addr &&
+				laddr->s_addr != SIN4(&proxy)->sin_addr.s_addr &&
+				pcbp.inp_fport == fport &&
+				pcbp.inp_lport == lport)
+			{
+				return (pcbp.inp_socket);
+			}
+		}
+#endif
+
 		if (pcbp.inp_faddr.s_addr == faddr->s_addr &&
 			pcbp.inp_laddr.s_addr == laddr->s_addr &&
 			pcbp.inp_fport == fport &&
@@ -245,7 +253,7 @@ static struct socket *getlist4(	void *arg,
 #endif
 
 /*
-** Return the user number for the connection owner
+** Return the UID of the connection owner
 */
 
 int get_user4(	in_port_t lport,
@@ -405,18 +413,24 @@ int masq(	int sock,
 				continue;
 		}
 
-		lport = htons(lport);
-		fport = htons(fport);
+		lport = ntohs(lport);
+		fport = ntohs(fport);
 
 		sin_setv4(nat.nat_inip.s_addr, &ss);
 
 		if (opt_enabled(FORWARD)) {
-			ret = fwd_request(sock, fport, lport, nat.nat_inport, &ss);
+			ret = fwd_request(sock, lport, lport, fport, &ss);
+
 			if (ret == 0)
 				return (0);
+			else {
+				char ipbuf[MAX_IPLEN];
 
-			debug("Forward to %s (%d %d) failed.",
-				inet_ntoa(nat.nat_inip), lport, nat.nat_inport);
+				get_ip(&ss, ipbuf, sizeof(ipbuf));
+
+				debug("Forward to %s (%d %d | %d %d) failed",
+					ipbuf, lport, fport, nat.nat_inport, nat.nat_outport);
+			}
 		}
 
 		ret = find_masq_entry(&ss, user, sizeof(user), os, sizeof(os));
