@@ -1,6 +1,6 @@
 /*
 ** oidentd.c - oidentd ident (rfc1413) implementation.
-** Copyright (C) 1998-2001 Ryan McCabe <odin@numb.org>
+** Copyright (C) 1998-2002 Ryan McCabe <odin@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -15,7 +15,7 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 **
-** $Id: oidentd.c,v 1.22 2001/11/12 15:37:25 odin Exp $
+** $Id: oidentd.c,v 1.28 2002/04/06 02:45:23 odin Exp $
 */
 
 #define _GNU_SOURCE
@@ -84,38 +84,36 @@ int main(int argc, char **argv) {
 
 	openlog("oidentd", LOG_PID | LOG_CONS | LOG_NDELAY, FACILITY);
 
-	if (read_config(config_file) == -1) {
-		o_log(NORMAL, "Error reading configuration file.");
+	if (read_config(config_file) != 0) {
+		o_log(NORMAL, "Error reading configuration file");
 		exit(-1);
 	}
 
 	if (go_background() == -1) {
-		o_log(NORMAL, "Fatal: Error creating daemon process.");
+		o_log(NORMAL, "Fatal: Error creating daemon process");
 		exit(-1);
 	}
 
 	listen_fds = setup_listen(addr, htons(listen_port));
 	if (listen_fds == NULL || listen_fds[0] == -1) {
-		o_log(NORMAL, "Fatal: Unable to setup listening socket.");
+		o_log(NORMAL, "Fatal: Unable to setup listening socket");
 		exit(-1);
 	}
 
-#ifdef USE_KMEM
-	if (k_open()) {
+	if (k_open() != 0) {
 		o_log(NORMAL, "Fatal: Can't open kmem device: %s", strerror(errno));
 		exit(-1);
 	}
-#endif
 
 	if (drop_privs(uid, gid) == -1) {
-		o_log(NORMAL, "Fatal: Couldn't drop privileges.");
+		o_log(NORMAL, "Fatal: Couldn't drop privileges");
 		exit(-1);
 	}
 
 #ifdef HAVE_LIBUDB
 	if (opt_enabled(USEUDB)) {
 		if (udb_init(UDB_ENV_BASE_KEY) == 0) {
-			o_log(NORMAL, "Fatal: Can't open UDB shared memory tables.");
+			o_log(NORMAL, "Fatal: Can't open UDB shared memory tables");
 			exit(-1);
 		}
 	}
@@ -160,10 +158,10 @@ int main(int argc, char **argv) {
 					++current_connections;
 
 					if (fork() == 0) {
-						int *p;
+						size_t idx;
 
-						for (p = listen_fds ; *p != -1 ; p++)
-							close(*p);
+						for (idx = 0 ; listen_fds[idx] != -1 ; ++idx)
+							close(listen_fds[idx]);
 
 						free(listen_fds);
 						alarm(timeout);
@@ -199,26 +197,21 @@ static int service_request(int sock) {
 	char suser[MAX_ULEN];
 	char host_buf[MAX_HOSTLEN];
 	char ip_buf[MAX_IPLEN];
-	struct sockaddr_storage temp;
 	struct sockaddr_storage laddr;
 	struct sockaddr_storage faddr;
 	struct passwd *pw, pwd;
 	static socklen_t socklen = sizeof(struct sockaddr_storage);
 
-	if (getpeername(sock, (struct sockaddr *) &temp, &socklen) != 0) {
+	if (getpeername(sock, (struct sockaddr *) &faddr, &socklen) != 0) {
 		debug("getpeername: %s", strerror(errno));
 		return (-1);
 	}
 
-	memcpy(&faddr, &temp, sizeof(faddr));
-
-	if (getsockname(sock, (struct sockaddr *) &temp, &socklen) != 0) {
+	if (getsockname(sock, (struct sockaddr *) &laddr, &socklen) != 0) {
 		debug("getsockname: %s", strerror(errno));
 		return (-1);
 	}
 
-	memcpy(&laddr, &temp, sizeof(laddr));
-
 #ifdef WANT_IPV6
 	if (laddr.ss_family == AF_INET6) {
 		if (!IN6_IS_ADDR_V4MAPPED(&SIN6(&laddr)->sin6_addr))
@@ -227,12 +220,10 @@ static int service_request(int sock) {
 			struct in_addr in4;
 
 			sin_extractv4(&SIN6(&laddr)->sin6_addr, &in4);
-			sin_setv4(in4.s_addr, &temp);
-			memcpy(&laddr, &temp, sizeof(laddr));
+			sin_setv4(in4.s_addr, &laddr);
 
 			sin_extractv4(&SIN6(&faddr)->sin6_addr, &in4);
-			sin_setv4(in4.s_addr, &temp);
-			memcpy(&faddr, &temp, sizeof(faddr));
+			sin_setv4(in4.s_addr, &faddr);
 		}
 	}
 #endif
@@ -311,8 +302,8 @@ static int service_request(int sock) {
 	if (pw == NULL) {
 		sockprintf(sock, "%d , %d : ERROR : %s\r\n",
 			lport, fport, ERROR("NO-USER"));
-		debug("getpwuid(%d): %s", con_uid, strerror(errno));
 
+		debug("getpwuid(%d): %s", con_uid, strerror(errno));
 		return (0);
 	} else
 		copy_pw(pw, &pwd);
@@ -364,7 +355,7 @@ static void free_pw(struct passwd *pw) {
 */
 
 static void sig_segv(int unused) {
-	o_log(NORMAL, "Got SIGSEGV.");
+	o_log(NORMAL, "Got SIGSEGV");
 	exit(-1);
 
 	(void) unused;
@@ -386,7 +377,7 @@ static void sig_child(int sig) {
 */
 
 static void sig_alarm(int unused) {
-	o_log(NORMAL, "Timeout for request.  Closing connection.");
+	o_log(NORMAL, "Timeout for request -- Closing connection");
 
 	exit(0);
 	(void) unused;
@@ -399,8 +390,8 @@ static void sig_alarm(int unused) {
 static void sig_hup(int unused) {
 	user_db_destroy();
 
-	if (read_config(CONFFILE) == -1) {
-		o_log(NORMAL, "Error reading configuration file.");
+	if (read_config(CONFFILE) != 0) {
+		o_log(NORMAL, "Error parsing configuration file");
 		exit(-1);
 	}
 
