@@ -1,6 +1,6 @@
 /*
 ** oidentd_masq.c - oidentd IP masquerading handler.
-** Copyright (C) 1998-2001 Ryan McCabe <odin@numb.org>
+** Copyright (C) 1998-2002 Ryan McCabe <odin@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -15,7 +15,7 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 **
-** $Id: oidentd_masq.c,v 1.24 2001/12/28 21:41:40 odin Exp $
+** $Id: oidentd_masq.c,v 1.29 2002/01/16 06:55:07 odin Exp $
 */
 
 #include <config.h>
@@ -74,6 +74,7 @@ static bool blank_line(const char *buf) {
 
 	return (true);
 }
+
 /*
 ** Parse the masquerading map file.
 ** Returns 0 on success, -1 on failure.
@@ -211,7 +212,7 @@ int find_masq_entry(struct sockaddr_storage *host,
 
 		p = strtok(NULL, " \t");
 		if (p == NULL) {
-			debug("[%s:%d] Missing OS parameter.",
+			debug("[%s:%d] Missing OS parameter",
 				MASQ_MAP, line_num, p);
 
 			goto failure;
@@ -329,7 +330,7 @@ out_fail:
 */
 
 static void fwd_alarm(int sig) {
-	o_log(NORMAL, "Forward timed out.");
+	o_log(NORMAL, "Forward timed out");
 	close(fsock);
 	siglongjmp(timebuf, sig);
 }
